EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_FillVersionGaps',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Ensures that there are no gaps in configuration file instance versions.'
GO

IF OBJECT_ID('[ConfigurationFiles_FillVersionGaps]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_FillVersionGaps]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_FillVersionGaps]
(
	@ConfigurationFile_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @InstanceGaps TABLE
	(
		[Instance_Name] VARCHAR(100) NOT NULL,
		[Version_Number] INT NOT NULL,
		[Count] INT NOT NULL
	)

	INSERT INTO @InstanceGaps
	(
		[Instance_Name],
		[Version_Number],
		[Count]
	)
	SELECT CFV.[Instance_Name],
		   [Version_Number] = MAX([Version_Number]),
		   [Count] = MAX(CFV_Max.[Max_Version_Number]) - MAX([Version_Number])
	  FROM [ConfigurationFileVersions] CFV
	       INNER JOIN (SELECT [ConfigurationFile_Id],
	                          [Max_Version_Number] = MAX([Version_Number])
	                     FROM [ConfigurationFileVersions]
	                    GROUP BY [ConfigurationFile_Id]) CFV_Max
			       ON CFV_Max.[ConfigurationFile_Id] = CFV.[ConfigurationFile_Id]
	 WHERE CFV.[ConfigurationFile_Id] = @ConfigurationFile_Id
	 GROUP BY CFV.[ConfigurationFile_Id], CFV.[Instance_Name]
	HAVING MAX(CFV.[Version_Number]) < MAX(CFV_Max.[Max_Version_Number])
	
	INSERT INTO [ConfigurationFileVersions]
	(
		[ConfigurationFile_Id],
		[Instance_Name],
		[Version_Number],
		[VersionNotes_Text],
		[File_Date],
		[File_Bytes],
		[CreatedBy_User_Name],
		[CreatedOn_Date]
	)
	SELECT CFV.[ConfigurationFile_Id],
	       CFV.[Instance_Name],
		   CFV.[Version_Number] + N.[Number],
		   NULL,
		   NULL,
		   NULL,
		   NULL,
		   NULL
	  FROM @InstanceGaps IG
	       INNER JOIN [Numbers] N
		           ON N.[Number] >= 1 AND N.[Number] <= IG.[Count]
		   INNER JOIN [ConfigurationFileVersions] CFV
		           ON CFV.[ConfigurationFile_Id] = @ConfigurationFile_Id
				  AND CFV.[Instance_Name] = IG.[Instance_Name]
				  AND CFV.[Version_Number] = IG.[Version_Number]

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [ConfigurationFiles_FillVersionGaps] TO [BuildMasterUser_Role]
GO
