EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_DeployBuild',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Marks a build and its associated release as deployed based on the settings in its pipeline.'
GO

IF OBJECT_ID('[Builds_DeployBuild]') IS NOT NULL DROP PROCEDURE [Builds_DeployBuild]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_DeployBuild]
(
	@Build_Id INT
)
AS
BEGIN

	SET NOCOUNT ON

    BEGIN TRY
	BEGIN TRANSACTION

		DECLARE @Release_Id INT
		DECLARE @Release_Number RELEASENUMBER
		DECLARE @Build_Number BUILDNUMBER
		DECLARE @ReleaseStatus_Name VARCHAR(9)
		DECLARE @BuildStatus_Name VARCHAR(8)
		DECLARE @Release_Sequence BIGINT
		DECLARE @Application_Id INT

		SELECT @Build_Number = B.[Build_Number],
		       @Release_Id = B.[Release_Id],
			   @Release_Number = R.[Release_Number],
			   @ReleaseStatus_Name = R.[ReleaseStatus_Name],
			   @BuildStatus_Name = B.[BuildStatus_Name],
			   @Release_Sequence = R.[Release_Sequence],
			   @Application_Id = B.[Application_Id]
		  FROM [Builds] B
		       LEFT JOIN [Releases] R
			          ON R.[Release_Id] = B.[Release_Id]
		 WHERE B.[Build_Id] = @Build_Id
				
        IF @ReleaseStatus_Name IS NOT NULL AND @ReleaseStatus_Name <> 'Active'
			RAISERROR('Can only deploy an active release.', 16, 1)

		IF @BuildStatus_Name <> 'Active'
			RAISERROR('Can only deploy an active build.', 16, 1)

	    UPDATE [Releases]
		   SET [ReleaseStatus_Name] = 'Deployed'
		 WHERE [Release_Id] = @Release_Id

		UPDATE [Builds]
		   SET [BuildStatus_Name] = 'Deployed'
		 WHERE [Build_Id] = @Build_Id

		UPDATE B
		   SET B.[BuildStatus_Name] = 'Rejected',
			   B.[RejectedBy_User_Name] = dbo.Session_GetUserName(),
			   B.[Rejected_Date] = GETUTCDATE()
		  FROM [Builds] B
		       INNER JOIN [Releases] R
			           ON R.[Release_Id] = B.[Release_Id]
		 WHERE R.[Release_Id] = @Release_Id
		   AND B.[BuildStatus_Name] = 'Active'

		INSERT INTO [ReleaseConfigurationFiles]
		(
			[Release_Id],
			[ConfigurationFile_Id],
			[Version_Number]
		)
		SELECT @Release_Id,
			   CF.[ConfigurationFile_Id],
			   CFV_Latest.[Version_Number]
		  FROM [ConfigurationFiles] CF
		       INNER JOIN [Deployables] D
			           ON D.[Deployable_Id] = CF.[Deployable_Id]
		       INNER JOIN (SELECT [ConfigurationFile_Id],
			                      [Version_Number] = MAX([Version_Number])
			                 FROM [ConfigurationFileVersions]
							GROUP BY [ConfigurationFile_Id]) CFV_Latest
					   ON CFV_Latest.[ConfigurationFile_Id] = CF.[ConfigurationFile_Id]
		 WHERE D.[Application_Id] = @Application_Id
		   AND CF.[ConfigurationFile_Id] NOT IN (SELECT [ConfigurationFile_Id]
		                                           FROM [ReleaseConfigurationFiles] RCF
												  WHERE RCF.[Release_Id] = @Release_Id)

		IF @Release_Number IS NOT NULL		
			EXEC [Events_RaiseEvent] 'RELDEP', @Application_Id, @Release_Number

	COMMIT
    END TRY BEGIN CATCH
	    IF XACT_STATE()<>0 ROLLBACK
	    EXEC [HandleError]
    END CATCH

END
GO

GRANT EXECUTE ON [Builds_DeployBuild] TO [BuildMasterUser_Role]
