EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Calendars_CreateOrUpdateCalendar',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Calendar_Id',
    /* Description_Text        */ 'Creates a new calendar or updates an existing one.'
GO

IF OBJECT_ID('[Calendars_CreateOrUpdateCalendar]') IS NOT NULL DROP PROCEDURE [Calendars_CreateOrUpdateCalendar]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Calendars_CreateOrUpdateCalendar]
(
	@Calendar_Name NVARCHAR(50),
    @CalendarType_Code CHAR(1),
    @Principal_Name NVARCHAR(100),
    @Calendar_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF (@Calendar_Id IS NULL)
	BEGIN
		INSERT INTO [Calendars] 
		(
            [Calendar_Name],
            [CalendarType_Code],
            [Principal_Name],
            [CreatedOn_Date],
            [CreatedBy_User_Name],
            [ModifiedOn_Date],
            [ModifiedBy_User_Name]
		)
		VALUES
		(
            @Calendar_Name,
            @CalendarType_Code,
            @Principal_Name,
            GETUTCDATE(),
            dbo.Session_GetUserName(),
            GETUTCDATE(),
            dbo.Session_GetUserName()
		)

		SET @Calendar_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [Calendars]
		   SET [Calendar_Name] = @Calendar_Name,
            [CalendarType_Code] = @CalendarType_Code,
            [Principal_Name] = @Principal_Name,
            [ModifiedOn_Date] = GETUTCDATE(),
            [ModifiedBy_User_Name] = dbo.Session_GetUserName()
         WHERE [Calendar_Id] = @Calendar_Id

	END


	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Calendars_CreateOrUpdateCalendar] TO [BuildMasterUser_Role]
