EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Dashboards_GetApplications',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'Applications_Extended,Applications_LatestDeployedReleases',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets an application summary for all applications in BuildMaster or a specific group of applications.'
GO


IF OBJECT_ID('[Dashboards_GetApplications]') IS NOT NULL DROP PROCEDURE [Dashboards_GetApplications]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Dashboards_GetApplications]
(
	@Application_Id INT = NULL,
    @ApplicationGroup_Id INT = NULL
)
AS
BEGIN

	SELECT AE.*
	  FROM [Applications_Extended] AE

	 WHERE ([Application_Id] = @Application_Id OR @Application_Id IS NULL)
       AND (@ApplicationGroup_Id IS NULL OR EXISTS(SELECT * 
                                                     FROM [ApplicationGroups] AG
                                              CROSS APPLY dbo.ApplicationGroups_GetAncestorGroups(AG.[ApplicationGroup_Id]) AGA
                                                    WHERE AGA.[ApplicationGroup_Id] = @ApplicationGroup_Id
                                                      AND AG.[ApplicationGroup_Id] = AE.[ApplicationGroup_Id])
            )
	 ORDER BY   
	          CASE WHEN AE.[ApplicationGroup_Id] IS NULL THEN 1 ELSE 0 END
	         ,[ApplicationGroup_Name]
	         ,[Application_Name]

	SELECT *
	  FROM [Applications_LatestDeployedReleases]
	 WHERE ([ApplicationGroup_Id] = @ApplicationGroup_Id OR @ApplicationGroup_Id IS NULL)
	   AND ([Application_Id] = @Application_Id OR @Application_Id IS NULL)
	 ORDER BY [Application_Id]

END
GO

GRANT EXECUTE ON [Dashboards_GetApplications] TO [BuildMasterUser_Role]
