EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'PackageSources_CreateOrUpdatePackageSource',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'PackageSource_Id',
    /* Description_Text        */ 'Creates a new package source or updates an existing one.'
GO

IF OBJECT_ID('[PackageSources_CreateOrUpdatePackageSource]') IS NOT NULL DROP PROCEDURE [PackageSources_CreateOrUpdatePackageSource]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [PackageSources_CreateOrUpdatePackageSource]
(
	@Feed_Url NVARCHAR(255),
	@Feed_Display_Url NVARCHAR(255),
    @PackageSource_Name NVARCHAR(50),
    @Credential_Name NVARCHAR(50),
	@PackageSourceType_Code CHAR(1),
    @PackageSource_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF (@PackageSource_Id IS NULL)
	BEGIN
		INSERT INTO [PackageSources] 
		(
            [Feed_Url],
			[Feed_Display_Url],
            [PackageSource_Name],
            [Credential_Name],
			[PackageSourceType_Code]
		)
		VALUES
		(
			@Feed_Url,
			@Feed_Display_Url,
            @PackageSource_Name,
            @Credential_Name,
			@PackageSourceType_Code
		)
		SET @PackageSource_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [PackageSources]
		   SET [Feed_Url] = @Feed_Url,
			   [Feed_Display_Url] = COALESCE(@Feed_Display_Url, [Feed_Display_Url]),
               [PackageSource_Name] = @PackageSource_Name,
               [Credential_Name] = @Credential_Name,
			   [PackageSourceType_Code] = @PackageSourceType_Code
         WHERE [PackageSource_Id] = @PackageSource_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [PackageSources_CreateOrUpdatePackageSource] TO [BuildMasterUser_Role]
